@@ -19,7 +19,7 @@ import utils
 import os
 import re
 import json
-from timestamp import html_link,html_script,html_img,all_url
+from timestamp import html_link,html_script,html_img,all_url,all as allt
 from deps import DepsFinder
 from replace import replace
 from jinja2 import Template,Environment,FileSystemLoader,TemplateNotFound,TemplateSyntaxError
@@ -28,13 +28,14 @@ _template_dir = C('template_dir')
 
 jinjaenv = Environment(loader = FileSystemLoader(utils.abspath(_template_dir),  C('encoding') ), extensions = ["jinja2.ext.do"] , autoescape = True )
 build_jinjaenv = Environment( loader = FileSystemLoader( os.path.join( os.getcwd() , C('build_dir'), _template_dir) ,  C('encoding') ))
+mgr_jinjaenv = Environment( loader = FileSystemLoader( os.path.join(BASE_DIR,'tpl') ,  C('encoding') ))
 
 def render_file(filename,data = None,noEnvironment = False,build = False):
     '''
     渲染文件
     '''
     if noEnvironment:
-        body = Template(utils.readfile(filename))#这里应为绝对路径
+        body = mgr_jinjaenv.get_template(filename)#Template(utils.readfile(filename))#这里应为绝对路径
     else:
         if build:
             body = build_jinjaenv.get_template(filename)
@@ -79,7 +80,7 @@ class TokenRender(object):
                 json_data = json.loads(content)
                 data.update(json_data)
             except Exception, e:
-                log.warn('[getdata]%s:%s'%(json_filepath,e))
+                e#log.warn('[getdata]%s:%s'%(json_filepath,e))
         return data
 
     @classmethod
@@ -97,19 +98,20 @@ class TokenRender(object):
             tpl_path = self.__token + "." + C('template_ext')
             html = render_file( tpl_path,data,False,build)
             if C('server_add_timestamp'):
-                html = html_script(html)
-                html = html_link(html)
-                html = html_img(html)
-                html = all_url(html)
+                #html = html_script(html)
+                #html = html_link(html)
+                #html = html_img(html)
+                #html = all_url(html)
+                html = allt(html)
             html = replace(html)
-            if not re.match(r'[\s\S]*?<html[\s\S]+?<body',html,re.I):
+            if not build and not re.match(r'[\s\S]*?<html[\s\S]+?<body',html,re.I):
                 #sub template
                 css_deps = self.__getDepsCss(html)
 
                 for tpl in self.__include_deps:
                     css = os.path.join('.',C('static_dir'),C('css_dir'),re.sub(r"\.%s"%C('template_ext'),".css",tpl))
                     css_deps.append(css)
-                subparent = os.path.join(BASE_DIR,"tpl",'subparent.tpl')
+                subparent = 'subparent.tpl'# os.path.join(BASE_DIR,"tpl",'subparent.tpl')
                 html = render_file(subparent,{'name': self.__token,'content': html,'required_css': css_deps},noEnvironment = True)
 
             html = removeCssDepsDeclaration(html)
